# Alerts

### Success alerts

    alert:success:This is a success alert! Yes, you can also use \n in here.

#### Example

This is a success alert! Yes, you can also use
in here.

### Info alerts

    alert:info:This is a info alert! Yes, you can also use \n in here.

#### Example

This is a info alert! Yes, you can also use
in here.

### Warning alerts

    alert:warning:This is a warning alert! Yes, you can also use \n in here.

#### Example

This is a warning alert! Yes, you can also use
in here.

### Danger alerts

    alert:danger:This is a danger alert! Yes, you can also use \n in here.

#### Example

This is a danger alert! Yes, you can also use
in here.